@@ -80,7 +80,7 @@ class ImagingPath(MatrixGroup):
 
         And the following figure will be plotted:
 
-        .. image:: ../images/ImagingPath.png
+        .. image:: /images/ImagingPath.png
                     :width: 70%
                     :align: center
     """
@@ -89,9 +89,9 @@ class ImagingPath(MatrixGroup):
 
         self._objectHeight = 10.0  # object height (full).
         self.objectPosition = 0.0  # always at z=0 for now.
-        self.fanAngle = None  # full fan angle for rays
-        self.fanNumber = 3  # number of points on object
-        self.rayNumber = 3  # number of rays in fan
+        self._fanAngle = None  # full fan angle for rays
+        self._fanNumber = 3  # number of points on object
+        self._rayNumber = 3  # number of rays in fan
 
         # Constants when calculating field stop
         self.precision = 0.000001
@@ -445,7 +445,7 @@ class ImagingPath(MatrixGroup):
 
         >>> path.display()
 
-        .. image:: ../../../images/apertureStop.png
+        .. image:: /images/apertureStop.png
             :width: 70%
             :align: center
 
@@ -484,6 +484,16 @@ class ImagingPath(MatrixGroup):
 
             return Stop(z=apertureStopPosition, diameter=apertureStopDiameter)
 
+    def hasApertureStop(self):
+        """ Returns True if this ImagingPath has an aperture stop.
+        The presence of a single finite diameter element is usually sufficient
+        to have an aperture stop."""
+
+        dist, diam = self.apertureStop()
+        if dist is not None:
+            return True
+        return False
+    
     def entrancePupil(self):
         """The entrance pupil is the image of the aperture stop
         as seen from the object. To obtain this image, we simply
@@ -512,7 +522,7 @@ class ImagingPath(MatrixGroup):
         >>> path.append(Lens(f=10,diameter=10,label="f=10"))
         >>> path.append(Space(d=10))
         >>> print('The (position,diameter) of entrance pupil:', path.entrancePupil())
-        The (position,diameter) of entrance pupil: (20.0, 5.0)
+        The (position,diameter) of entrance pupil: Stop(z=20.0, diameter=5.0)
 
         """
 
@@ -570,7 +580,7 @@ class ImagingPath(MatrixGroup):
 
         >>> path.display()
 
-        .. image:: ../../../images/apertureStop.png
+        .. image:: /images/apertureStop.png
             :width: 70%
             :align: center
 
@@ -628,6 +638,20 @@ class ImagingPath(MatrixGroup):
 
         return Stop(z=fieldStopPosition, diameter=fieldStopDiameter)
 
+    def hasFieldStop(self):
+        """ Returns True if this ImagingPath has a field stop.
+        
+        The presence of a single finite diameter element is not sufficient
+        to have a field stop: we must have at least two finite aperture 
+        elements (maybe more depending on position) to have a field stop.
+        If the system has no field stop, then the fieldOfView will be infinite.
+        """
+
+        dist, diam = self.fieldStop()
+        if dist is not None:
+            return True
+        return False
+
     def fieldOfView(self):
         """The field of view is the length visible before the chief
         rays on either side are blocked by the field stop.
@@ -726,9 +750,19 @@ class ImagingPath(MatrixGroup):
 
         return chiefRay.y
 
-    def imageSize(self):
-        """The image size is the object field of view multiplied by magnification.
-        This value is independent from the height of the object.
+    def imageSize(self, useObject=False):
+        """ The actual formal definition of image size is the object field of
+        view multiplied by magnification. This value is independent from the height of
+        the object. However, if the FOV is infinite, this may not be what the user is
+        expecting. In this case a warning is printed and we offer the possibility to
+        use `objectHeight` from the class.
+        
+        Parameters
+        ----------
+
+        useObject : bool default  False
+            Whether or not we use the finite `objectHeight` provided in the class
+            instead of the field of view to calculate the image size.
 
         Returns
         -------
@@ -749,12 +783,19 @@ class ImagingPath(MatrixGroup):
         size of the image : 9.999998574656525
 
         """
-        fieldOfView = self.fieldOfView()
         (distance, conjugateMatrix) = self.forwardConjugate()
         if conjugateMatrix is None:
             return float("+inf")
 
         magnification = conjugateMatrix.A
+
+        if useObject:
+            return abs(self.objectHeight * magnification)
+
+        fieldOfView = self.fieldOfView()
+        if not np.isfinite(fieldOfView):
+            warnings.warn('Field of view is infinite. You can pass useObject=True to use the finite objectHeight.', category=BeginnerHint)
+
         return abs(fieldOfView * magnification)
 
     def lagrangeInvariant(self):
@@ -798,6 +839,9 @@ class ImagingPath(MatrixGroup):
         import matplotlib.patches as p
 
         principal = self.principalRay()
+        if principal is None:
+            print("There is no Field Stop in this system. We cannot produce a report.")
+            return
         axial = self.axialRay()
         Iap = abs(self.lagrangeInvariant()) # corresponds to Zhe in the article
 
@@ -851,7 +895,7 @@ class ImagingPath(MatrixGroup):
         print(" Collection efficiency from ratio of system to source invariants: {0:.1f}%".format(Iap/Is*100))
         stopPosition, stopDiameter = self.apertureStop()
         print(" Efficiency limited by {0:.1f} mm diameter of AS at z={1:.1f}".format(stopDiameter, stopPosition))
-        print(" For 100% efficiency, the system would require an increase of {0:.2f}⨉ in detection NA with same FOV".format(Is/Iap))
+        #print(" For 100% efficiency, the system would require an increase of {0:.2f}⨉ in detection NA with same FOV".format(Is/Iap))
         print("\nVignetting")
         print("----------")
         print("Relative efficiency: {0:.1f}% of maximum for this system".format(100*len(notBlocked)/(len(vignettedBlocked)+len(notBlocked))))
@@ -892,7 +936,7 @@ class ImagingPath(MatrixGroup):
         z = 0
         for i, element in enumerate(self.elements):
             if z < zStart < z + element.L:
-                assert type(element).__name__ is 'Space', 'The position of the rays cannot be in the same ' \
+                assert type(element).__name__ == 'Space', 'The position of the rays cannot be in the same ' \
                                                           'position of another element.'
                 if backwards:
                     newElements = [Space(zStart - z)]
@@ -909,7 +953,7 @@ class ImagingPath(MatrixGroup):
         raise ValueError('The position of the rays does not fit in any spaces.')
 
     def display(self, rays=None, raysList=None, removeBlocked=True, comments=None,
-                onlyPrincipalAndAxialRays=None, limitObjectToFieldOfView=None, interactive=True, filePath=None):
+                onlyPrincipalAndAxialRays=None, limitObjectToFieldOfView=None, interactive=True, filePath=None): #pragma: no cover 
         """ Display the optical system and trace the rays.
 
         Parameters
@@ -944,10 +988,10 @@ class ImagingPath(MatrixGroup):
                 self.figure.designParams['showFOV'] = False
             else:
                 warnings.warn('No rays were provided for the display. '
-                              'Using principal and axial rays.', category=Warning)
+                              'Using principal and axial rays.', category=BeginnerHint)
                 if self.principalRay() is None and self.axialRay() is None:
                     warnings.warn('Principal and axial rays are not defined for this system. '
-                                  'Using default ObjectRays.', category=Warning)
+                                  'Using default ObjectRays.', category=BeginnerHint)
 
         if 'ObjectRays' not in [type(rays).__name__ for rays in raysList]:
             if self.fanAngle is None:
@@ -987,13 +1031,19 @@ class ImagingPath(MatrixGroup):
                      limitObjectToFieldOfView=limitObjectToFieldOfView,
                      interactive=False, filePath=filePath)
 
-    def displayWithObject(self, diameter, z=0, fanAngle=None, fanNumber=3, rayNumber=3, removeBlocked=True, comments=None):
+    def displayWithObject(self, diameter, fanAngle=None, fanNumber=3, rayNumber=3, removeBlocked=True, comments=None): #pragma: no cover 
         """ Display the optical system and trace the rays.
 
         Parameters
         ----------
         diameter : float
             Diameter of the object.
+        fanAngle : float (default=None)
+            the half angle for the rays.  If None, it will be chosen optimally
+        fanNumber : float (default=3)
+            the number of rays originating from a point
+        rayNumber : float (default=3)
+            the number of points on the object from which rays will emerge
         removeBlocked : bool (Optional)
             If True, the blocked rays are removed (default=False)
         comments : string
@@ -1003,7 +1053,7 @@ class ImagingPath(MatrixGroup):
         self._objectHeight = diameter
         if fanAngle is None:
             fanAngle = np.tan(self.figure.displayRange / 2 / self.L / 5)
-        rays = ObjectRays(diameter, halfAngle=fanAngle, H=fanNumber, T=rayNumber, z=z)
+        rays = ObjectRays(diameter, halfAngle=fanAngle, H=fanNumber, T=rayNumber)
 
         self.display(rays=rays, raysList=None, removeBlocked=removeBlocked, comments=comments,
                      onlyPrincipalAndAxialRays=False,
