@@ -2,12 +2,14 @@ from .ray import *
 from .gaussianbeam import *
 from .rays import *
 from .interface import *
+from .utils import *
 
 from typing import List
 import multiprocessing
 import sys
 import math
 import warnings
+from numpy import isfinite
 
 """ We start with general, useful namedtuples to simplify management of values """
 from typing import NamedTuple
@@ -32,17 +34,8 @@ class Conjugate(NamedTuple):
     d: float = None
     transferMatrix:'Matrix' = None
 
-
-def warningLineFormat(message, category, filename, lineno, line=None):
-    return '\n%s:%s\n%s:%s\n' % (filename, lineno, category.__name__, message)
-
-
-warnings.formatwarning = warningLineFormat
-
-
 # todo: fix docstrings since draw-related methods were removed
 
-
 class Matrix(object):
     r"""A matrix and an optical element that can transform a ray or another
     matrix.
@@ -134,6 +127,7 @@ class Matrix(object):
             frontIndex=1.0,
             backIndex=1.0,
             apertureDiameter=float('+Inf'),
+            apertureNA=float('+Inf'),
             label=''
     ):
         # Ray matrix formalism
@@ -148,6 +142,9 @@ class Matrix(object):
         if apertureDiameter <= 0:
             raise ValueError("The aperture diameter must be strictly positive.")
         self.apertureDiameter = apertureDiameter
+        if apertureNA <= 0:
+            raise ValueError("The aperture NA must be strictly positive.")
+        self.apertureNA = apertureNA
 
         # First and last interfaces. Used for BFL and FFL
         self.frontVertex = frontVertex
@@ -391,18 +388,18 @@ class Matrix(object):
 
         outputRay = Ray()
 
-        if rightSideRay.isNotBlocked:
+        if rightSideRay.isBlocked:
+            outputRay = rightSideRay
+        else:
             outputRay.y = self.A * rightSideRay.y + self.B * rightSideRay.theta
             outputRay.theta = self.C * rightSideRay.y + self.D * rightSideRay.theta
             outputRay.z = self.L + rightSideRay.z
             outputRay.apertureDiameter = self.apertureDiameter
 
-            if abs(rightSideRay.y) > abs(self.apertureDiameter / 2.0):
+            if abs(rightSideRay.y) > self.apertureDiameter/2 or abs(rightSideRay.theta) > self.apertureNA:
                 outputRay.isBlocked = True
             else:
                 outputRay.isBlocked = rightSideRay.isBlocked
-        else:
-            outputRay = rightSideRay
 
         return outputRay
 
@@ -443,7 +440,7 @@ class Matrix(object):
         if rightSideBeam.n != self.frontIndex:
             msg = "The gaussian beam is not tracking the index of refraction properly {0} {1}".format(
                 rightSideBeam.n, self.frontIndex)
-            warnings.warn(msg, UserWarning)
+            raise RuntimeError(msg)
 
         qprime = (complex(self.A) * q + complex(self.B)) / (complex(self.C) * q + complex(self.D))
 
@@ -451,7 +448,7 @@ class Matrix(object):
         outputBeam.z = self.L + rightSideBeam.z
         outputBeam.n = self.backIndex
 
-        if abs(outputBeam.w) > self.apertureDiameter / 2:
+        if abs(outputBeam.w) > self.apertureDiameter/2:
             outputBeam.isClipped = True
         else:
             outputBeam.isClipped = rightSideBeam.isClipped
@@ -536,16 +533,15 @@ class Matrix(object):
         return [self]
 
     def opticalInvariant(self, ray1, ray2, z=0):
-        """
-        The optical invariant is a quantity that is conserved
-        for any two rays in the system. It is very general and
-        any two rays can be used. It is often seen with the
-        chief ray and marginal ray in an imaging system, in which
-        case it is called the Lagrange invariant. 
-        In ImagingPath(), the principal and axial rays can be used,
-        in which case the optical invariant is called the Lagrange Invariant,
-        and is the maximal optical invariant between two rays that guarantees 
-        neither one will be blocked.
+        """ The optical invariant is a quantity that is conserved for any two
+        rays in the system. It is very general and any two rays can be used. At a
+        given position z, it is  simply n✕(θ₁y₂ - θ₂y₁), where n is the index at that
+        z.
+        
+        In an ImagingPath, it will often be calculated with the principal and
+        axial rays, in which case the optical invariant is called the Lagrange
+        Invariant. The Lagrange invariant is the maximal optical invariant
+        that guarantees neither rays will be blocked.
 
         Parameters
         ----------
@@ -650,7 +646,7 @@ class Matrix(object):
         rayTrace = []
         if isinstance(ray, Ray):
             if self.L > 0:
-                if abs(ray.y) > self.apertureDiameter / 2:
+                if abs(ray.y) > self.apertureDiameter/2:
                     ray.isBlocked = True
                 rayTrace.append(ray)
 
@@ -731,7 +727,7 @@ class Matrix(object):
         >>> print('The properties of the first input ray:\n', Tr[0][0])
         The properties of the first input ray:
          y =  0.000
-        theta =  0.827
+        theta =  0.153
         z = 0.000
 
 
@@ -739,7 +735,7 @@ class Matrix(object):
         >>> print('The properties of the first output ray:\n', Tr[0][1])
         The properties of the first output ray:
          y =  0.000
-        theta =  0.827
+        theta =  0.153
         z = 2.000
 
         See Also
@@ -876,8 +872,8 @@ class Matrix(object):
                 outputRaysList += rays.rays
 
             return Rays(rays=outputRaysList)
-        except:
-            warnings.warn("Multiprocessing failed. Falling back to slower code.", UserWarning)
+        except Exception as err:
+            warnings.warn("Multiprocessing failed with: '{0}'. Falling back to slower code.".format(err), ExpertNote)
             return self.traceManyThrough(inputRays=inputRays, progress=progress)
 
     def profileFromRayTraces(self, rayTraces, z=float("+inf")):
@@ -966,13 +962,13 @@ class Matrix(object):
         >>> M1= Matrix(A=1,B=0,C=-1/5,D=1,physicalLength=0,label='Lens')
         >>> f1=M1.focalDistances()
         >>> print('focal distances:' , f1)
-        focal distances: (5.0, 5.0)
+        focal distances: FocalLengths(f1=5.0, f2=5.0)
 
         This function has the same out put as effectiveFocalLengths()
 
         >>> f2=M1.effectiveFocalLengths()
         >>> print('focal distances:' , f2)
-        focal distances: (5.0, 5.0)
+        focal distances: FocalLengths(f1=5.0, f2=5.0)
         """
 
         return self.effectiveFocalLengths()
@@ -1005,12 +1001,12 @@ class Matrix(object):
         >>> M1= Matrix(A=1,B=0,C=-1/5,D=1,physicalLength=0,label='Lens')
         >>> f2=M1.effectiveFocalLengths()
         >>> print('focal distances:' , f2)
-        focal distances: (5.0, 5.0)
+        focal distances: FocalLengths(f1=5.0, f2=5.0)
 
         This function has the same out put as effectiveFocalLengths()
         >>> f1=M1.focalDistances()
         >>> print('focal distances:' , f1)
-        focal distances: (5.0, 5.0)
+        focal distances: FocalLengths(f1=5.0, f2=5.0)
 
         """
 
@@ -1149,13 +1145,13 @@ class Matrix(object):
         >>> M1= Matrix(A=1,B=0,C=-1/5,D=1,physicalLength=4,frontVertex=-1,backVertex=5,label='Lens')
         >>> Position0=M1.focusPositions(z=0)
         >>> print('focal positions (F,B):' , Position0)
-        focal positions (F,B): (-5.0, 9.0)
+        focal positions (F,B): CardinalPoint(z1=-5.0, z2=9.0)
 
         And if we move object 2 units:
 
         >>> Position2=M1.focusPositions(z=2)
         >>> print('focal positions (F,B):' , Position2)
-        focal positions (F,B): (-3.0, 11.0)
+        focal positions (F,B): CardinalPoint(z1=-3.0, z2=11.0)
 
         See Also
         --------
@@ -1190,7 +1186,7 @@ class Matrix(object):
         >>> M1= Matrix(A=1,B=0,C=-1/5,D=1,physicalLength=3,frontVertex=-1,backVertex=5,label='Lens')
         >>> Position0=M1.principalPlanePositions(z=0)
         >>> print('PP positions (F,B):' , Position0)
-        PP positions (F,B): (0.0, 3.0)
+        PP positions (F,B): PrincipalPlanes(z1=0.0, z2=3.0)
 
         See Also
         --------
@@ -1357,17 +1353,16 @@ class Matrix(object):
 
         The original object:
 
-        .. image:: ../../../images/flipOrientation_before.png
+        .. image:: /images/flipOrientation_before.png
             :width: 70%
             :align: center
 
         The flipped object:
 
-        .. image:: ../../../images/flipOrientation_after.png
+        .. image:: /images/flipOrientation_after.png
             :width: 70%
             :align: center
 
-
         See Also
         --------
         raytracing.Matrix
@@ -1406,8 +1401,9 @@ class Matrix(object):
             The half height of the optical element
         """
         halfHeight = 4  # FIXME: keep a minimum half height when infinite ?
+
         if self.apertureDiameter != float('+Inf'):
-            halfHeight = self.apertureDiameter / 2.0  # real half height
+            halfHeight = self.apertureDiameter/2  # real half height
         return halfHeight
 
     def display(self):
@@ -1515,7 +1511,7 @@ class Lens(Matrix):
             The half height of the optical element
         """
         if self.apertureDiameter != float('+Inf'):
-            self._physicalHalfHeight = self.apertureDiameter / 2.0  # real half height
+            self._physicalHalfHeight = self.apertureDiameter/2  # real half height
         return self._physicalHalfHeight
 
     @property
@@ -1958,7 +1954,7 @@ class Aperture(Matrix):
     If the ray is beyond the finite diameter, the ray is blocked.
     """
 
-    def __init__(self, diameter, label=''):
+    def __init__(self, diameter, NA=float("+inf"), label=''):
         super(
             Aperture,
             self).__init__(
@@ -1968,4 +1964,5 @@ class Aperture(Matrix):
             D=1,
             physicalLength=0,
             apertureDiameter=diameter,
+            apertureNA=NA,
             label=label)
