@@ -70,9 +70,8 @@ class MatrixGroup(Matrix):
         if len(self.elements) != 0:
             lastElement = self.elements[-1]
             if lastElement.backIndex != matrix.frontIndex:
-                if isinstance(matrix, Space):  # For Space(), we fix it
-                    msg = "Fixing mismatched indices between last element and appended Space(). Use Space(d=someDistance, n=someIndex)."
-                    warnings.warn(msg, UserWarning)
+                if isinstance(matrix, Space):  
+                    # For Space(), we fix it
                     matrix.frontIndex = lastElement.backIndex
                     matrix.backIndex = matrix.frontIndex
                 else:
@@ -241,11 +240,11 @@ class MatrixGroup(Matrix):
         >>> from raytracing import *
         >>> system = MatrixGroup([Space(10), Lens(10), Space(10), Space(10), Lens(10), Space(10)])
         >>> print(f"Initial magnification: {system.magnification()}")
-        Initial magnification: (-1.0, -1.0)
+        Initial magnification: Magnification(transverse=-1.0, angular=-1.0)
 
         >>> system[3:] = MatrixGroup([Space(5), Lens(5), Space(5)])
         >>> print(f"Final magnification: {system.magnification()}")
-        Final magnification: (-0.5, -2.0)
+        Final magnification: Magnification(transverse=-0.5, angular=-2.0)
 
         See Also
         --------
@@ -403,7 +402,7 @@ class MatrixGroup(Matrix):
         """Trace the input ray from first element until after the last element,
         indicating if the ray was blocked or not.
 
-        Parameter
+        Parameters
         ---------
         inputRay : object of ray class
             A ray with height y and angle theta
