@@ -172,7 +172,7 @@ class Rays:
         >>> plt.xlabel('Height of Rays')
         >>> plt.show()
 
-        .. image:: ../../../images/Histogram.png
+        .. image:: /images/Histogram.png
                     :width: 70%
                     :align: center
 
@@ -251,7 +251,7 @@ class Rays:
         >>> plt.xlabel('Angle of Rays')
         >>> plt.show()
 
-        .. image:: ../../../images/AngleHist.png
+        .. image:: /images/AngleHist.png
                     :width: 70%
                     :align: center
 
@@ -305,7 +305,7 @@ class Rays:
         >>> inputRays = RandomUniformRays(yMin=minHeight, yMax=maxHeight, thetaMin=minTheta,thetaMax=maxTheta, maxCount=nRays)
         >>> inputRays.display()
 
-        .. image:: ../../../images/displayRays.png
+        .. image:: /images/displayRays.png
                     :width: 70%
                     :align: center
 
@@ -500,7 +500,7 @@ class UniformRays(Rays):
     >>> inputRays = UniformRays(yMin=minHeight, yMax=maxHeight, thetaMin=minTheta,thetaMax=maxTheta, N=nRays, M=10)
     >>> inputRays.display()
 
-    .. image:: ../images/UniformRays.png
+    .. image:: /images/UniformRays.png
                     :width: 70%
                     :align: center
 
@@ -564,7 +564,7 @@ class LambertianRays(Rays):
     >>> inputRays = LambertianRays(yMin=minHeight, yMax=maxHeight)
     >>> inputRays.display()
 
-    .. image:: ../images/LambertianRays.png
+    .. image:: /images/LambertianRays.png
                     :width: 70%
                     :align: center
 
@@ -693,7 +693,7 @@ class RandomUniformRays(RandomRays):
         >>> inputRays.display()
 
 
-        .. image:: ../images/RandomUniformRays.png
+        .. image:: /images/RandomUniformRays.png
                     :width: 70%
                     :align: center
 
@@ -744,7 +744,7 @@ class RandomLambertianRays(RandomRays):
     >>> inputRays.display()
 
 
-    .. image:: ../images/RandomLambertianRays.png
+    .. image:: /images/RandomLambertianRays.png
                 :width: 70%
                 :align: center
 
@@ -767,8 +767,8 @@ class RandomLambertianRays(RandomRays):
         while (True):
             theta = self.thetaMin + np.random.random() * (self.thetaMax - self.thetaMin)
             intensity = np.cos(theta)
-            seed = np.random.random()
-            if seed < intensity:
+            randomValue = np.random.random()
+            if randomValue < intensity:
                 break
 
         y = self.yMin + np.random.random() * (self.yMax - self.yMin)
