@@ -419,7 +419,7 @@ class AC254_100_A(AchromatDoubletLens):
                                     label="AC254-100-A", wavelength=wavelength, wavelengthRef=0.5876)
 
 class AC254_125_A(AchromatDoubletLens):
-    """ AC254_125_A
+    """ AC254-125-A
 
     .. csv-table::
         :header: Parameter, value
@@ -440,25 +440,25 @@ class AC254_125_A(AchromatDoubletLens):
 
     Notes
     -----
-    More info: https://www.thorlabs.com/newgrouppage9.cfm?objectgroup_id=120
+        More info: https://www.thorlabs.com/newgrouppage9.cfm?objectgroup_id=120
+        As of May 31 2020, the calculated edge thickness does not match
+        the product page. There does not seem to be another place where
+        the information can be validated (the PDF doesn't show the edge thickness).
+        https://www.thorlabs.com/newgrouppage9.cfm?objectgroup_id=120.
+        Because everything else is fine in all calculations, to avoid
+        warnings, we are setting te=5.3 mm, even if the web site says 5.0 mm.
+        All properties are correct except that, and it has no impact on calculations
+        (it is just a sanity check).
     """
 
     def __init__(self, wavelength= None):
-        """
-        Notes
-        -----
-        As of May 31 2020, the calculated edge thickness does not match
-        the product page. There does not seem to be another place where 
-        the information can be validated (the PDF doesn't show the edge thickness).
-        https://www.thorlabs.com/newgrouppage9.cfm?objectgroup_id=120
-        """
-        super(AC254_125_A,self).__init__(fa=125.0,fb=122.0, R1=77.6,R2=-55.9, R3=-160.8, 
-                                    tc1=4.0, tc2=2.8, te=5.0, n1=None, mat1=N_BK7, n2=None, mat2=N_SF5, diameter=25.4,
+        super(AC254_125_A,self).__init__(fa=125.0,fb=122.0, R1=77.63,R2=-55.92, R3=-160.82, 
+                                    tc1=4.0, tc2=2.83, te=5.3, n1=None, mat1=N_BK7, n2=None, mat2=N_SF5, diameter=25.4,
                                     url='https://www.thorlabs.com/newgrouppage9.cfm?objectgroup_id=120',
                                     label="AC254-125-A", wavelength=wavelength, wavelengthRef=0.5876)
 
 class AC254_150_A(AchromatDoubletLens):
-    """ AC254_150_A
+    """ AC254-150-A
 
     .. csv-table::
         :header: Parameter, value
@@ -489,7 +489,7 @@ class AC254_150_A(AchromatDoubletLens):
                                     label="AC254-150-A", wavelength=wavelength, wavelengthRef=0.5876)
 
 class AC254_200_A(AchromatDoubletLens):
-    """ AC254_200_A
+    """ AC254-200-A
 
     .. csv-table::
         :header: Parameter, value
@@ -520,7 +520,7 @@ class AC254_200_A(AchromatDoubletLens):
                                     label="AC254-200-A", wavelength=wavelength, wavelengthRef= 0.5876)
 
 class AC254_250_A(AchromatDoubletLens):
-    """ AC254_250_A
+    """ AC254-250-A
 
     .. csv-table::
         :header: Parameter, value
@@ -551,7 +551,7 @@ class AC254_250_A(AchromatDoubletLens):
                                     label="AC254-250-A", wavelength=wavelength, wavelengthRef=0.5876)
 
 class AC254_300_A(AchromatDoubletLens):
-    """ AC254_300_A
+    """ AC254-300-A
 
     .. csv-table::
         :header: Parameter, value
@@ -582,7 +582,7 @@ class AC254_300_A(AchromatDoubletLens):
                                     label="AC254-300-A", wavelength=wavelength, wavelengthRef=0.5876)
 
 class AC254_400_A(AchromatDoubletLens):
-    """ AC254_400_A
+    """ AC254-400-A
 
     .. csv-table::
         :header: Parameter, value
@@ -613,7 +613,7 @@ class AC254_400_A(AchromatDoubletLens):
                                     label="AC254-400-A", wavelength=wavelength, wavelengthRef=0.5876)
 
 class AC254_500_A(AchromatDoubletLens):
-    """ AC254_500_A
+    """ AC254-500-A
 
     .. csv-table::
         :header: Parameter, value
@@ -644,7 +644,7 @@ class AC254_500_A(AchromatDoubletLens):
                                     label="AC254-500-A", wavelength=wavelength, wavelengthRef= 0.5876)
 
 class AC254_050_B(AchromatDoubletLens):
-    """ AC254_050_B
+    """ AC254-050-B
 
     .. csv-table::
         :header: Parameter, value
@@ -676,7 +676,7 @@ class AC254_050_B(AchromatDoubletLens):
 
 
 class AC508_075_B(AchromatDoubletLens):
-    """ AC508_075_B
+    """ AC508-075-B
 
     .. csv-table::
         :header: Parameter, value
@@ -707,7 +707,7 @@ class AC508_075_B(AchromatDoubletLens):
                                     label="AC508-075-B", wavelength=wavelength, wavelengthRef=0.855)
 
 class AC508_080_B(AchromatDoubletLens):
-    """ AC508_080_B
+    """ AC508-080-B
 
     .. csv-table::
         :header: Parameter, value
@@ -738,7 +738,7 @@ class AC508_080_B(AchromatDoubletLens):
                                     label="AC508-080-B", wavelength=wavelength, wavelengthRef=0.855)
 
 class AC508_100_B(AchromatDoubletLens):
-    """ AC508_100_B
+    """ AC508-100-B
 
     .. csv-table::
         :header: Parameter, value
@@ -769,7 +769,7 @@ class AC508_100_B(AchromatDoubletLens):
                                     label="AC508-100-B", wavelength=wavelength, wavelengthRef=0.855)
 
 class AC508_150_B(AchromatDoubletLens):
-    """ AC508_150_B
+    """ AC508-150-B
 
     .. csv-table::
         :header: Parameter, value
@@ -800,7 +800,7 @@ class AC508_150_B(AchromatDoubletLens):
                                     label="AC508-150-B", wavelength=wavelength, wavelengthRef=0.855)
 
 class AC508_200_B(AchromatDoubletLens):
-    """ AC508_200_B
+    """ AC508-200-B
 
     .. csv-table::
         :header: Parameter, value
@@ -831,7 +831,7 @@ class AC508_200_B(AchromatDoubletLens):
                                     label="AC508-200-B", wavelength=wavelength, wavelengthRef=0.855)
 
 class AC508_250_B(AchromatDoubletLens):
-    """ AC508_250_B
+    """ AC508-250-B
 
     .. csv-table::
         :header: Parameter, value
@@ -862,7 +862,7 @@ class AC508_250_B(AchromatDoubletLens):
                                     label="AC508-250-B", wavelength=wavelength, wavelengthRef=0.855)
 
 class AC508_300_B(AchromatDoubletLens):
-    """ AC508_300_B
+    """ AC508-300-B
 
     .. csv-table::
         :header: Parameter, value
@@ -893,7 +893,7 @@ class AC508_300_B(AchromatDoubletLens):
                                     label="AC508-300-B", wavelength=wavelength, wavelengthRef=0.855)
 
 class AC508_400_B(AchromatDoubletLens):
-    """ AC508_400_B
+    """ AC508-400-B
 
     .. csv-table::
         :header: Parameter, value
@@ -924,7 +924,7 @@ class AC508_400_B(AchromatDoubletLens):
                                     label="AC508-400-B", wavelength=wavelength, wavelengthRef=0.855)
 
 class AC508_500_B(AchromatDoubletLens):
-    """ AC508_500_B
+    """ AC508-500-B
 
     .. csv-table::
         :header: Parameter, value
@@ -955,7 +955,7 @@ class AC508_500_B(AchromatDoubletLens):
                                     label="AC508-500-B", wavelength=wavelength, wavelengthRef=0.855)
 
 class AC508_750_B(AchromatDoubletLens):
-    """ AC508_750_B
+    """ AC5s08-750-B
 
     .. csv-table::
         :header: Parameter, value
@@ -986,7 +986,7 @@ class AC508_750_B(AchromatDoubletLens):
                                     label="AC508-750-B", wavelength=wavelength, wavelengthRef=0.855)
 
 class AC508_1000_B(AchromatDoubletLens):
-    """ AC508_1000_B
+    """ AC508-1000-B
 
     .. csv-table::
         :header: Parameter, value
@@ -1017,7 +1017,7 @@ class AC508_1000_B(AchromatDoubletLens):
                                     label="AC508-1000-B", wavelength=wavelength, wavelengthRef=0.855)
 
 class LA1608_A(SingletLens):
-    """ LA1608_A
+    """ LA1608-A
 
     .. csv-table::
         :header: Parameter, value
@@ -1043,7 +1043,7 @@ class LA1608_A(SingletLens):
                                       label="LA1608_A", wavelength=wavelength, wavelengthRef=0.5876)
 
 class LA1134_A(SingletLens):
-    """ LA1134_A
+    """ LA1134-A
 
     .. csv-table::
         :header: Parameter, value
@@ -1069,7 +1069,7 @@ class LA1134_A(SingletLens):
                                       label="LA1134_A", wavelength=wavelength, wavelengthRef=0.5876)
 
 class LA1131_A(SingletLens):
-    """ LA1131_A
+    """ LA1131-A
 
     .. csv-table::
         :header: Parameter, value
@@ -1095,7 +1095,7 @@ class LA1131_A(SingletLens):
                                       label="LA1131_A", wavelength=wavelength, wavelengthRef=0.5876)
 
 class LA1422_A(SingletLens):
-    """ LA1422_A
+    """ LA1422-A
 
     .. csv-table::
         :header: Parameter, value
@@ -1121,7 +1121,7 @@ class LA1422_A(SingletLens):
                                       label="LA1422_A", wavelength=wavelength, wavelengthRef=0.5876)
         
 class LA1805_A(SingletLens):
-    """ LA1805_A
+    """ LA1805-A
 
     .. csv-table::
         :header: Parameter, value
@@ -1147,7 +1147,7 @@ class LA1805_A(SingletLens):
                                       label="LA1805_A", wavelength=wavelength, wavelengthRef=0.5876)
 
 class LA1274_A(SingletLens):
-    """ LA1274_A
+    """ LA1274-A
 
     .. csv-table::
         :header: Parameter, value
